//-----------------------------------------------------------------------------
// <copyright file="BATStatus.cs" company="eQ-3 Entwicklung GmbH">
//  Copyright (c) 2010 eQ-3 Entwicklung GmbH
// </copyright>
//-----------------------------------------------------------------------------

namespace Eq3.misc.usb_bat
{
    using System.Windows;
    using System.Xml.Serialization;

    /// <summary>
    /// Status des Bedien und Anzeige Terminals
    /// </summary>
    public class BATStatus : DependencyObject
    {
        // Using a DependencyProperty as the backing store for InkPosition.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty InkPositionProperty =
            DependencyProperty.Register("InkPosition", typeof(byte), typeof(BATStatus), new UIPropertyMetadata((byte)0x00));
        
        // Using a DependencyProperty as the backing store for InkChange.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty InkChangeProperty =
            DependencyProperty.Register("InkChange", typeof(byte), typeof(BATStatus), new UIPropertyMetadata((byte)0x00));
        
        // Using a DependencyProperty as the backing store for InkPressed.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty InkPressedProperty =
            DependencyProperty.Register("InkPressed", typeof(bool), typeof(BATStatus), new UIPropertyMetadata(false));
        
        // Using a DependencyProperty as the backing store for InkLongPressed.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty InkLongPressedProperty =
            DependencyProperty.Register("InkLongPressed", typeof(bool), typeof(BATStatus), new UIPropertyMetadata(false));
        
        // Using a DependencyProperty as the backing store for InkIsNotPressed.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty InkIsNotPressedProperty =
            DependencyProperty.Register("InkIsNotPressed", typeof(bool), typeof(BATStatus), new UIPropertyMetadata(false));
        
        // Using a DependencyProperty as the backing store for APressed.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty APressedProperty =
            DependencyProperty.Register("APressed", typeof(bool), typeof(BATStatus), new UIPropertyMetadata(false));
        
        // Using a DependencyProperty as the backing store for ALongPressed.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty ALongPressedProperty =
            DependencyProperty.Register("ALongPressed", typeof(bool), typeof(BATStatus), new UIPropertyMetadata(false));
        
        // Using a DependencyProperty as the backing store for AIsNotPressed.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty AIsNotPressedProperty =
            DependencyProperty.Register("AIsNotPressed", typeof(bool), typeof(BATStatus), new UIPropertyMetadata(false));
        
        // Using a DependencyProperty as the backing store for BPressed.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty BPressedProperty =
            DependencyProperty.Register("BPressed", typeof(bool), typeof(BATStatus), new UIPropertyMetadata(false));
        
        // Using a DependencyProperty as the backing store for BLongPressed.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty BLongPressedProperty =
            DependencyProperty.Register("BLongPressed", typeof(bool), typeof(BATStatus), new UIPropertyMetadata(false));
        
        // Using a DependencyProperty as the backing store for BIsNotPressed.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty BIsNotPressedProperty =
            DependencyProperty.Register("BIsNotPressed", typeof(bool), typeof(BATStatus), new UIPropertyMetadata(false));
        
        public BATStatus()
        {

        }

        /// <summary>
        /// Aktuelle Position des Inkrementalgeber
        /// </summary>
        public byte InkPosition
        {
            get { return (byte)GetValue(InkPositionProperty); }
            set { SetValue(InkPositionProperty, value); }
        }

        /// <summary>
        /// Vernderung der Position des Inkrementalgebers
        /// </summary>
        public byte InkChange
        {
            get { return (byte)GetValue(InkChangeProperty); }
            set { SetValue(InkChangeProperty, value); }
        }

        /// <summary>
        /// Ob der Taster des Inkrementalgebers gedrck war
        /// </summary>
        public bool InkPressed
        {
            get { return (bool)GetValue(InkPressedProperty); }
            set { SetValue(InkPressedProperty, value); }
        }

        /// <summary>
        /// Ob der Taster des Inkrementalgebers lange gedrck war
        /// </summary>
        public bool InkLongPressed
        {
            get { return (bool)GetValue(InkLongPressedProperty); }
            set { SetValue(InkLongPressedProperty, value); }
        }

        /// <summary>
        /// Ob der Taster des Inkrementalgebers aktuell nicht gedrck ist
        /// </summary>
        public bool InkIsNotPressed
        {
            get { return (bool)GetValue(InkIsNotPressedProperty); }
            set { SetValue(InkIsNotPressedProperty, value); }
        }

        /// <summary>
        /// Ob der Taster A gedrck war
        /// </summary>        
        public bool APressed
        {
            get { return (bool)GetValue(APressedProperty); }
            set { SetValue(APressedProperty, value); }
        }

        /// <summary>
        /// Ob der Taster A lange gedrck war
        /// </summary>        
        public bool ALongPressed
        {
            get { return (bool)GetValue(ALongPressedProperty); }
            set { SetValue(ALongPressedProperty, value); }
        }

        /// <summary>
        /// Ob der Taster A aktuell nicht gedrckt ist
        /// </summary>        
        public bool AIsNotPressed
        {
            get { return (bool)GetValue(AIsNotPressedProperty); }
            set { SetValue(AIsNotPressedProperty, value); }
        }

        /// <summary>
        /// Ob der Taster B gedrck war
        /// </summary>        
        public bool BPressed
        {
            get { return (bool)GetValue(BPressedProperty); }
            set { SetValue(BPressedProperty, value); }
        }

        /// <summary>
        /// Ob der Taster B lange gedrck war
        /// </summary>        
        public bool BLongPressed
        {
            get { return (bool)GetValue(BLongPressedProperty); }
            set { SetValue(BLongPressedProperty, value); }
        }

        /// <summary>
        /// Ob der Taster A aktuell nicht gedrckt ist
        /// </summary>        
        public bool BIsNotPressed
        {
            get { return (bool)GetValue(BIsNotPressedProperty); }
            set { SetValue(BIsNotPressedProperty, value); }
        }

        /// <summary>
        /// Erzeugt ein BATStatus Objekt aus dem ByteArray
        /// </summary>
        /// <param name="value">Status als ByteArray</param>
        /// <returns>aktueller BATStatus</returns>
        public static BATStatus FromBytes(byte[] value)
        {
            BATStatus result = new BATStatus();

            result.InkPressed = (value[0] & 0x01) != 0;
            result.APressed = (value[0] & 0x02) != 0;
            result.BPressed = (value[0] & 0x04) != 0;

            result.InkLongPressed = (value[0] & 0x10) != 0;
            result.ALongPressed = (value[0] & 0x20) != 0;
            result.BLongPressed = (value[0] & 0x40) != 0;

            result.InkPosition = value[1];
            result.InkChange = value[2];

            result.InkIsNotPressed = (value[3] & 0x01) != 0;
            result.AIsNotPressed = (value[3] & 0x02) != 0;
            result.BIsNotPressed = (value[3] & 0x04) != 0;

            return result;
        }
    }
}